#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clash-lib
version:              1.4.3
visibility:           public
id:                   clash-lib-1.4.3-JdcxphnCuKfBGkl6hTCoQE
key:                  clash-lib-1.4.3-JdcxphnCuKfBGkl6hTCoQE
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2019, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - As a library

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * The CoreHW internal language: SystemF + Letrec + Case-decomposition

    * The normalisation process that brings CoreHW in a normal form that can be
    converted to a netlist

    * Blackbox/Primitive Handling


    Front-ends (for: parsing, typecheck, etc.) are provided by separate packages:

    * <https://hackage.haskell.org/package/clash-ghc GHC/Haskell Frontend>

    * <https://github.com/christiaanb/Idris-dev Idris Frontend>


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  26b6c9826ea694c8295f4fb00edd858e
exposed:              True
exposed-modules:
    Clash.Annotations.BitRepresentation.ClashLib Clash.Backend
    Clash.Backend.SystemVerilog Clash.Backend.VHDL
    Clash.Backend.Verilog Clash.Core.DataCon Clash.Core.EqSolver
    Clash.Core.Evaluator.Types Clash.Core.FreeVars Clash.Core.Literal
    Clash.Core.Name Clash.Core.PartialEval
    Clash.Core.PartialEval.AsTerm Clash.Core.PartialEval.Monad
    Clash.Core.PartialEval.NormalForm Clash.Core.Pretty
    Clash.Core.Subst Clash.Core.Term Clash.Core.TermInfo
    Clash.Core.TermLiteral Clash.Core.TermLiteral.TH
    Clash.Core.Termination Clash.Core.TyCon Clash.Core.Type
    Clash.Core.TysPrim Clash.Core.Util Clash.Core.Var Clash.Core.VarEnv
    Clash.Debug Clash.Driver Clash.Driver.Manifest Clash.Driver.Types
    Clash.Edalize.Edam Clash.Netlist Clash.Netlist.BlackBox
    Clash.Netlist.BlackBox.Parser Clash.Netlist.BlackBox.Types
    Clash.Netlist.BlackBox.Util Clash.Netlist.Id
    Clash.Netlist.Id.Common Clash.Netlist.Id.Internal
    Clash.Netlist.Id.SystemVerilog Clash.Netlist.Id.VHDL
    Clash.Netlist.Id.Verilog Clash.Netlist.Types Clash.Netlist.Util
    Clash.Normalize Clash.Normalize.DEC
    Clash.Normalize.PrimitiveReductions Clash.Normalize.Strategy
    Clash.Normalize.Transformations Clash.Normalize.Types
    Clash.Normalize.Util Clash.Pretty Clash.Primitives.DSL
    Clash.Primitives.GHC.Int Clash.Primitives.GHC.Literal
    Clash.Primitives.GHC.Word Clash.Primitives.Intel.ClockGen
    Clash.Primitives.Sized.ToInteger Clash.Primitives.Sized.Vector
    Clash.Primitives.Types Clash.Primitives.Util
    Clash.Primitives.Verification Clash.Rewrite.Combinators
    Clash.Rewrite.Types Clash.Rewrite.Util Clash.Rewrite.WorkFree
    Clash.Unique Clash.Util Clash.Util.Graph Clash.Util.Interpolate
    Data.Text.Prettyprint.Doc.Extra

hidden-modules:
    Clash.Annotations.TopEntity.Extra Control.Applicative.Extra
    Data.Aeson.Extra Data.List.Extra Data.Map.Ordered.Extra
    Data.Primitive.ByteArray.Extra Data.Semigroup.Monad.Extra
    Data.Set.Ordered.Extra GHC.BasicTypes.Extra GHC.SrcLoc.Extra
    Paths_clash_lib

import-dirs:          /usr/lib/ghc-9.0.2/site-local/clash-lib-1.4.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/clash-lib-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/clash-lib-1.4.3
hs-libraries:         HSclash-lib-1.4.3-JdcxphnCuKfBGkl6hTCoQE
depends:
    aeson-1.5.6.0-BBhdcnlV5J5JNtwcCn5l4o
    aeson-pretty-0.8.9-82qN58L6oIPL8tYpbQeIT5
    ansi-terminal-0.11-7Sg6KtenVNR9Ce5shok5FD array-0.5.4.0
    attoparsec-0.14.3-DhMOAcVvvhtBRFS2FUPWxv base-4.15.1.0
    base16-bytestring-1.0.2.0-2QhMZqBZCvKHLMDpR0Nrwa binary-0.8.8.0
    bytestring-0.10.12.1 clash-prelude-1.4.3-3rYf1uIW2ua6RUlxZlmcTT
    concurrent-supply-0.1.8-2ryiiOb9L0G2XtPmqyNF0q containers-0.6.4.1
    cryptohash-sha256-0.11.102.1-Gr5gf87jNQMEy3pScGv9Xu
    data-binary-ieee754-0.4.4-6nKeQnWkGoLJGejCHaRaWS
    data-default-0.7.1.1-EcFn1KqENcc3dlLa7FIl7R deepseq-1.4.5.0
    directory-1.3.6.2 dlist-1.0-F00OxiD1dC249OyRKVGlo2
    errors-2.3.0-AMf4swi6TfI2g0Jb1DBx7t exceptions-0.10.4
    extra-1.7.10-znvSYUQOXfCxP9OaYRJ3s filepath-1.4.2.1 ghc-9.0.2
    ghc-bignum-1.1 ghc-boot-th-9.0.2
    hashable-1.3.5.0-8uEDmbS1YdCBqBDHH62nE1
    haskell-src-meta-0.8.7-65mJBdDZ2LQ6JI4qljSZy2
    hint-0.9.0.5-MiAUWTi8rttFBBe5muiP
    interpolate-0.2.1-G8b7ZaaENR32sJx6rPZwF2
    lens-5.1-90rUFaXMNykIIo8x6oLg1g mtl-2.2.2
    ordered-containers-0.2.2-3ZJFCOHv4Xt5NYft4y5Gmm
    parsers-0.12.10-GkVSTlU68oV7PdBB12qDr4
    pretty-show-1.10-30ddFMLbEm1DQ0GcmAHjnN
    prettyprinter-1.7.1-ETDLxKPKcph8icxqVOzYLo
    primitive-0.7.3.0-HsqtLhuAIqYHZIsIWpkf26 process-1.6.13.2
    reducers-3.12.4-3Z7AHEVzpLfJh9b2hrPMpU template-haskell-2.17.0.0
    temporary-1.3-134tyXPVqJTLwJyw9wcjiB
    terminal-size-0.3.2.1-FigLoTMV11v1o9pkAK81G8 text-1.2.5.0
    text-show-3.9.2-B3QpkRroHhzI534uRHBXGK time-1.9.3
    transformers-0.5.6.2 trifecta-2.1.2-IMMOJ2gZx7IFy307ZWKmcr
    unordered-containers-0.2.15.0-BthaKnOuVSgJmoPoerzXSZ
    utf8-string-1.0.2-3qDihrmHI404jlTProSRo6
    vector-0.12.3.1-AuXeyw9aHek8rgyiKRxwpj
    vector-binary-instances-0.2.5.2-K2drRalh9Xl5yMbvIxdeWh

haddock-interfaces:   /usr/share/doc/haskell-clash-lib/html/clash-lib.haddock
haddock-html:         /usr/share/doc/haskell-clash-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

